This patch works around a bug in ircd-ratbox-1.5-3.  Whilst remote klines
should never be issued server <-> server without a reason field, 1.5-3
allows this.  ratbox-2.0.6 and earlier will classify this as a protocol
violation and drop the locally connected uplink that sent it the message.

This patch alters the behaviour to simply silently ignore remote klines
without a reason field, rather than dropping our uplink.  This patch *MUST*
be applied after ircd-ratbox-2.0.6+kline.diff

To apply the patch:
  cd /path/to/source/modules/
  patch -p0 < ircd-ratbox-2.0.6+remotekline.diff
  make
  make install

Then on irc: /quote modrestart

--- m_kline.old	2005-01-26 23:49:24.000000000 +0000
+++ m_kline.c	2005-01-26 23:50:12.000000000 +0000
@@ -56,7 +56,7 @@
 
 struct Message kline_msgtab = {
 	"KLINE", 0, 0, 0, MFLG_SLOW,
-	{mg_unreg, mg_not_oper, {ms_kline, 6}, {ms_kline, 6}, {me_kline, 5}, {mo_kline, 3}}
+	{mg_unreg, mg_not_oper, {ms_kline, 5}, {ms_kline, 5}, {me_kline, 5}, {mo_kline, 3}}
 };
 
 struct Message unkline_msgtab = {
@@ -237,6 +237,12 @@
 {
 	int tkline_time = atoi(parv[2]);
 
+	/* 1.5-3 allows sending without a reason parameter, hack around it
+	 * so that we dont drop server links when it happens --anfl
+	 */
+	if(parc < 6 || EmptyString(parv[5]))
+		return 0;
+
 	propagate_generic(source_p, "KLINE", parv[1], CAP_KLN,
 			"%d %s %s :%s",
 			tkline_time, parv[3], parv[4], parv[5]);
